#ifdef GL_ES
precision mediump float;
#endif

uniform sampler2D myTexture0;
uniform sampler2D myTexture1;
uniform sampler2D myTexture2;
uniform sampler2D myTexture3;
uniform float ambientLightEnabled;
uniform float topRange, bottomRange;
uniform float levelTop, levelBottom;

varying float attPlayer, v;
varying vec3 vNormal;
varying float groundLevel;
varying vec3 vWorldVertexPos;


vec4 getComponent(vec4 c, float min, float max, float t) {
    float sm = 0.02;
    return c * smoothstep(min-sm, min+sm, t) * (1.0 - smoothstep(max-sm, max+sm, t));
}

void main (void)
{

	vec4 sceneLight = ((gl_FrontLightModelProduct.sceneColor * gl_FrontMaterial.ambient) + 
		(gl_LightSource[0].ambient * gl_FrontMaterial.ambient))*ambientLightEnabled;
	
	vec4 playerLight = 
	(gl_FrontLightModelProduct.sceneColor * gl_FrontMaterial.ambient) + 
	(gl_LightSource[1].ambient * gl_FrontMaterial.ambient)*attPlayer;
	
	vec4 light = sceneLight+playerLight;
	
	light.r = min(1.0, light.r);
	light.g = min(1.0, light.g);
	light.b = min(1.0, light.b);
		
	
	vec4 beachColor = texture2D(myTexture0, gl_TexCoord[0].st);
	vec4 grassColor = texture2D(myTexture1, gl_TexCoord[0].st);
	vec4 rockColor = texture2D(myTexture2, gl_TexCoord[0].st);
	vec4 rock2Color = texture2D(myTexture3, gl_TexCoord[0].st);

	if ( v > 0.0)
	{
		beachColor = texture2D( myTexture0, gl_TexCoord[1].st);
		grassColor = texture2D( myTexture1, gl_TexCoord[1].st);
		rockColor = texture2D( myTexture2, gl_TexCoord[1].st);
		rock2Color = texture2D(myTexture3, gl_TexCoord[1].st);
	}
	if ( v < 0.0 )
	{
		beachColor = texture2D( myTexture0, gl_TexCoord[2].st);
		grassColor = texture2D( myTexture1, gl_TexCoord[2].st);
		rockColor = texture2D( myTexture2, gl_TexCoord[2].st);
		rock2Color = texture2D(myTexture3, gl_TexCoord[2].st);
	}
	
	vec4 tc = getComponent(grassColor, bottomRange-1.0, topRange, groundLevel);
	if(vWorldVertexPos.y-bottomRange <= 1.0 && vWorldVertexPos.y-bottomRange >=0.0)
	{
		  tc = mix(beachColor, grassColor, vWorldVertexPos.y-bottomRange);
	}
	if(vWorldVertexPos.y-bottomRange >= -1.0 && vWorldVertexPos.y-bottomRange <0.0)
	{
		  tc = beachColor;
	}
	
	vec4 rockFinalColor = rock2Color; 
	if(vWorldVertexPos.y >= levelBottom && vWorldVertexPos.y <= levelBottom + 1.0)
	{
		  rockFinalColor = mix(rockColor, rock2Color, vWorldVertexPos.y-levelBottom);
	}
	if(vWorldVertexPos.y <= levelTop && vWorldVertexPos.y >= levelTop - 1.0)
	{
		  rockFinalColor = mix(rockColor, rock2Color, levelTop - vWorldVertexPos.y);
	}
	if(vWorldVertexPos.y < levelBottom || vWorldVertexPos.y > levelTop)
	{	
		rockFinalColor = rockColor;
	}
	
	float st = dot(vec3(0,1,0), vNormal);
	st = smoothstep(0.7, 0.7 + 0.15, st);
	tc = mix(rockFinalColor, tc, st);
	
	gl_FragColor = vec4(tc*light);
}